/*
 * Copyright 1999-2016 The OpenSSL Project Authors. All Rights Reserved.
 *
 * Licensed under the OpenSSL license (the "License").  You may not use
 * this file except in compliance with the License.  You can obtain a copy
 * in the file LICENSE in the source distribution or at
 * https://www.openssl.org/source/license.html
 */

#ifdef __cplusplus
extern "C" {
#endif

#ifndef HEADER_PEM_H
int ERR_load_PEM_strings(void);
#endif

#ifdef __cplusplus
}
#endif
